Module errors

Module errors 

This module holds some pre-made error types to eases your usage of deserr

Re-exports

pub use json::JsonError;
pub use query_params::QueryParamError;

Modules

helpers
Provide generic function that could be useful when creating your own error type.
json
This module implements the error messages of json deserialization errors. We try to generate the best possible human-readable description of the error.
query_params
This module implements the error messages of query parameters deserialization errors. We try to generate the best possible human-readable description of the error.